.. SPECTRAX documentation master file.

.. image:: SPECTRAX_logo.png
   :width: 200px
   :align: center
   :target: https://github.com/uwplasma/SPECTRAX

.. image:: https://img.shields.io/badge/GitHub-Repository-blue
   :target: https://github.com/uwplasma/SPECTRAX
   :alt: GitHub repository
   :width: 100px
   :align: center

-------------------------

SPECTRAX documentation
=========================

Welcome to SPECTRAX!
This is a Python package in JAX to perform plasma simulations
using a Hermite-Fourier decomposition.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started